import CodeMirror from "codemirror";

CodeMirror.defineMode("luau", function () {
    var keywords = {
        and: true,
        break: true,
        do: true,
        else: true,
        elseif: true,
        end: true,
        false: true,
        for: true,
        function: true,
        if: true,
        in: true,
        local: true,
        nil: true,
        not: true,
        or: true,
        repeat: true,
        return: true,
        then: true,
        true: true,
        until: true,
        while: true,
    };

    return {
        startState: function () {
            return { inComment: false };
        },

        token: function (stream, state) {
            if (stream.match("--")) {
                stream.skipToEnd();
                return "comment";
            }

            if (stream.eatSpace()) return null;

            var ch = stream.next();
            if (ch === '"' || ch === "'") {
                stream.skipTo(ch);
                return "string";
            }

            if (/\d/.test(ch)) {
                stream.eatWhile(/[\w\.]/);
                return "number";
            }

            if (/\w/.test(ch)) {
                stream.eatWhile(/\w/);
                var word = stream.current();
                if (keywords[word]) {
                    return "keyword";
                }
            }

            return null;
        },
    };
});

CodeMirror.defineMIME("text/x-luau", "luau");
